package hello.corba;

import org.omg.CORBA.*;
import org.omg.CosNaming.*;

import hello.corba.generated.*;

public class HelloClient {
    
    public static void main (String[] args) {

        try {
            // create and initialize the ORB
            ORB orb = ORB.init(args, null);

            // get the root naming context
            org.omg.CORBA.Object objRef = orb.resolve_initial_references("NameService");
            // Use NamingContextExt instead of NamingContext. This is 
            // part of the Interoperable naming Service.  
            NamingContextExt ncRef = NamingContextExtHelper.narrow(objRef);

            System.out.println("----- Usando parametros que sao objetos remotos -----");
            // resolve the Object Reference
            HelloRpRemote helloRp = HelloRpRemoteHelper.narrow(ncRef.resolve_str("hellocorba_rp"));

            // We now have a local instance, and can call its methods
            // Print HelloRemote (call toString())
            System.out.println("Remote object: " + helloRp);
                        
            System.out.println("\nResult of helloRp.sayHello(): " + helloRp.sayHello());
            System.out.println("Result of helloRp.getMessage().getNome(): " + helloRp.getMessage().getNome());
            System.out.println("Result of helloRp.getCirculo(): " + helloRp.getCirculo().toStringRemote());

            System.out.println("----- Nomes e Strings -----");
            
            System.out.println("\nCalling helloRp.sayThis(\"Goodbye, Helder!\"): ");
            helloRp.sayThis("Goodbye, Helder!");
            System.out.println("Result of helloRp.sayHello(): " + helloRp.sayHello());
            System.out.println("Result of helloRp.getMessage().getNome(): " + helloRp.getMessage().getNome());

            System.out.println("\nCalling helloRp.getMessage().setNome(\"Hi, you guys!\"): ");
            helloRp.getMessage().setNome("Hi, you guys!");
            System.out.println("Result of helloRp.sayHello(): " + helloRp.sayHello());
            System.out.println("Result of helloRp.getMessage().getNome(): " + helloRp.getMessage().getNome());
            
            System.out.println("\nCalling helloRp.setMessage(helloRp.createNome(\"Bye, bye!\")): ");
            helloRp.setMessage(helloRp.createNome("Bye, bye!"));
            System.out.println("Result of helloRp.sayHello(): " + helloRp.sayHello());
            System.out.println("Result of helloRp.getMessage().getNome(): " + helloRp.getMessage().getNome());

            System.out.println("----- Circulos e Pontos -----");
            
            System.out.println("\nCalling helloRp.createCirculo(50, helloRp.createPonto(30, 40)): ");
            helloRp.setCirculo(helloRp.createCirculo(50, helloRp.createPonto(30, 40)));
            System.out.println("Result of helloRp.getCirculo(): " + helloRp.getCirculo().toStringRemote());
            System.out.println("Result of helloRp.getCirculo().getOrigem(): " + helloRp.getCirculo().getOrigem().toStringRemote());

            System.out.println("\nCalling helloRp.getCirculo().setOrigem(helloRp.createPonto(300,400)): ");
            helloRp.getCirculo().setOrigem(helloRp.createPonto(300,400));
            System.out.println("Result of helloRp.getCirculo(): " + helloRp.getCirculo().toStringRemote());
            System.out.println("Result of helloRp.getCirculo().getOrigem(): " + helloRp.getCirculo().getOrigem().toStringRemote());
            
            System.out.println("\nCalling helloRp.getCirculo().getOrigem().setX(3000): ");
            helloRp.getCirculo().getOrigem().setX(3000);
            System.out.println("Result of helloRp.getCirculo(): " + helloRp.getCirculo().toStringRemote());
            System.out.println("Result of helloRp.getCirculo().getOrigem(): " + helloRp.getCirculo().getOrigem().toStringRemote());
            
        } catch (Exception e) {
            if (e instanceof RuntimeException) throw (RuntimeException)e;
            System.out.println("No object is bound to 'hellocorba_rp'. " + e);
            e.printStackTrace();
        }
    }
    
}
