package hello.corba;

import org.omg.CORBA.*;
import org.omg.CosNaming.*;
import org.omg.PortableServer.*;

import hello.corba.generated.*;

public class HelloServer {

    public static void main (String[] args) {

        try {

            // create and initialize the ORB
            ORB orb = ORB.init(args, System.getProperties());

            // get reference to rootpoa & activate the POAManager
            POA rootPOA = POAHelper.narrow( orb.resolve_initial_references("RootPOA") );
            rootPOA.the_POAManager().activate();

            // create servant and register it with the ORB
            
            // Create remote object that uses remote object parameters in methods
            // Create remote parameter objects
            PontoImpl probj = new PontoImpl(3, 4);
            org.omg.CORBA.Object ptoRef = rootPOA.servant_to_reference(probj);
            PontoRemote pr = PontoRemoteHelper.narrow(ptoRef);
            
            CirculoImpl crobj = new CirculoImpl(5, pr);
            org.omg.CORBA.Object circRef = rootPOA.servant_to_reference(crobj);
            CirculoRemote cr = CirculoRemoteHelper.narrow(circRef);
            
            NomeImpl nrobj = new NomeImpl("Hello, World!");
            org.omg.CORBA.Object nomeRef = rootPOA.servant_to_reference(nrobj);
            NomeRemote nr = NomeRemoteHelper.narrow(nomeRef);

            HelloRpImpl helloRp = new HelloRpImpl(nr, cr);
            
            helloRp.setORB(orb);
            helloRp.initPOA();

            // get object reference from the servant
            org.omg.CORBA.Object ref = rootPOA.servant_to_reference(helloRp);
            HelloRpRemote helloRef = HelloRpRemoteHelper.narrow(ref);

            // get the root naming context
            org.omg.CORBA.Object objRef = orb.resolve_initial_references("NameService");
            // Use NamingContextExt which is part of the Interoperable
            // Naming Service (INS) specification.
            NamingContextExt ncRef = NamingContextExtHelper.narrow(objRef);

            // bind the Object Reference
            NameComponent path[] = ncRef.to_name( "hellocorba_rp" );
            ncRef.rebind(path, helloRef);

            System.out.println("Remote object bound to 'hellocorba_rp'. Server ready to receive requests.");

            // wait for invocations from clients
            orb.run();

        } catch (Exception e) {
            if (e instanceof RuntimeException) throw (RuntimeException)e;
            System.out.println("" + e);
            e.printStackTrace();
        }

    }

}
