package hello.rmi;

import java.rmi.*;

import hello.*;
import hello.unicast.*; // RMI Remote Object Implementations

public class HelloServer {
    
    public static void main (String[] args) throws java.net.MalformedURLException {
        
        // Security Manager: requires policy file - see cap03/build.xml and cap03/lib
        if (System.getSecurityManager() == null) {
            System.setSecurityManager(new RMISecurityManager());
        }

        try {
            // Create remote object that uses local object parameters in methods
            // Create stored objects
            Circulo c = new Circulo(5, new Ponto(3, 4));
            Nome n = new Nome("Hello, World!");
            
            HelloRemote hello = new HelloImpl(n, c);
        
            // Create remote object that uses remote object parameters in methods
            // Create remote parameter objects
            CirculoRemote cr = new CirculoImpl(5, new PontoImpl(3, 4));
            NomeRemote nr = new NomeImpl("Hello, World!");
            
            HelloRpRemote helloRp = new HelloRpImpl(nr, cr);
        
            // Bind objects to RMI Registry
            Naming.rebind("hellormi", hello);
            System.out.println("Remote object bound to 'hellormi'.");
            Naming.rebind("hellormi_rp", helloRp);
            System.out.println("Remote object bound to 'hellormi_rp'. Server ready to receive requests.");

        } catch (RemoteException e) {
            System.out.println("" + e);
            e.printStackTrace();
        }
    }
    
}
