package client;

import loja.*;
import java.rmi.*;
import javax.naming.*;
import java.math.BigDecimal;

/**
 * Obtem uma fabrica de produtos e, atraves dela, cria alguns
 * produtos remotos.
 */
public class ProdutoClient {
	
	public static String jndiName = "loja/produtos";
    
    public static void main(String[] args) throws Exception {
		String hostname = "localhost";
		if (args.length > 0) {
			hostname = args[0];
		}
        try {
			java.util.Properties props = System.getProperties();
			props.load(ClassLoader.getSystemResourceAsStream("jndi.properties"));
			Context ctx = new InitialContext(props);
            Object obj = ctx.lookup(jndiName);
            ProdutoFactory fabrica = (ProdutoFactory) 
				javax.rmi.PortableRemoteObject.narrow(obj, ProdutoFactory.class);
				
			Produto[] p = new Produto[3];
			p[0] = fabrica.criar("Folhas de Cactus", new BigDecimal(30.00), 5);
			p[1] = fabrica.criar("Comida digital", new BigDecimal(120.00), 3);
			p[2] = fabrica.criar("Vento em garrafa", new BigDecimal(17.00), 12);
			
			System.out.println("----- Produtos criados -----");
			for (int i = 0; i < p.length; i++) {
				System.out.println("Produto: cdigo: " + p[i].getCodigo() +
											"; nome: " + p[i].getNome() + 
											"; preco: $" + p[i].getPreco() + 
											"; qte.: " + p[i].getQuantidade());
			}
			
			System.out.println("Adicionando mais 6 itens em "+p[1].getCodigo()+"...");
			p[1].addItens(6);
			System.out.println("Alterando preco de "+p[0].getCodigo()+" para 35.00...");
			p[0].setPreco(new BigDecimal(35.00));
			System.out.println("Mudando nome de "+p[2].getCodigo()+"...");
			p[2].setNome("Furacao em garrafa");
			
			System.out.println("----- Produtos -----");
			for (int i = 0; i < p.length; i++) {
				System.out.println("Produto: cdigo: " + p[i].getCodigo() +
											"; nome: " + p[i].getNome() + 
											"; preco: $" + p[i].getPreco() + 
											"; qte.: " + p[i].getQuantidade());
			}
        
        } catch (NamingException e) {
            System.out.println("Erro de JNDI:  " + e + ".\n");
        } catch (RemoteException e) {
            System.out.println("Erro de comunicao com o servidor: " + e + "\n");
        } catch (Exception e) { 
			System.out.println("Erro: " + e + "\n");
     	}
    }
}
